##  Detailed Guides
To learn more about the integration, refer to the following guides:
  * [Configuring the SAP Cloud ALM Integration](https://help.sap.com/docs/leanix/ea/sap-discovery-configuring-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to integrate SAP LeanIX with SAP Cloud ALM to automate the discovery of SAP systems, services, and integration flows."): Set up the discovery of your SAP landscape.
  * [Enabling Discovered Flows](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered flows in SAP Cloud ALM enable automatic identification and visualization of real integration flows between SAP systems, supporting integration mapping, dependency analysis, and interface documentation. This feature helps organizations gain visibility into active system communications and streamline interface management.") (Optional): Enable interface discovery through SAP Cloud ALM Integration & Exception Monitoring.
  * [SAP Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered products, services, and extensions from your SAP landscape appear in the SAP discovery inbox. Learn how to create, link, and reject fact sheets related to discovered items."): Review the discovered SAP systems and link them to fact sheets.


YesNo
Send
